@@ -244,17 +244,29 @@ def parse_body(body: Type[BaseModel]) -> Tuple[Dict[str, MediaType], dict]:
             components_schemas[name] = Schema(**value)
 
     if content is None:
-        print("Warning: "
-              f"{body.__name__}'s properties is empty, and"
-              f"{body.__name__}'s schema is set to object.")
+        if schema.get('type', 'object') == 'array' and len(definitions):
+            title = list(definitions.values())[0].get('title')
+            schema_kwargs = {
+                "type": "array",
+                "items": {
+                    "$ref": f"{OPENAPI3_REF_PREFIX}/{title}"
+                }
+            }
+        else:
+            print("Warning: "
+                  f"{body.__name__}'s properties is empty, and"
+                  f"{body.__name__}'s schema is set to object.")
+
+            schema_kwargs = {
+                "type": "object",
+            }
+
 
         content = {
             "application/json": MediaType(
                 **{
                     "schema": Schema(
-                        **{
-                            "type": "object"
-                        }
+                        **schema_kwargs
                     )
                 }
             )
